@@ -1,20 +1,7 @@
 /*
-  Copyright (c) 2017 Volker Krause <vkrause@kde.org>
+  SPDX-FileCopyrightText: 2017 Volker Krause <vkrause@kde.org>
 
-   This library is free software; you can redistribute it and/or modify it
-   under the terms of the GNU Library General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or (at your
-   option) any later version.
-
-   This library is distributed in the hope that it will be useful, but WITHOUT
-   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-   License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to the
-   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-   02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "calendarhandler.h"
@@ -143,8 +130,27 @@ private Q_SLOTS:
         ICalFormat format;
         format.load(refCal, icalFile);
 
-        const auto event = CalendarHandler::findEvent(refCal, postproc.result().at(0));
-        QVERIFY(event);
+        const auto events = CalendarHandler::findEvents(refCal, postproc.result().at(0));
+        QCOMPARE(events.size(), 1);
+        QVERIFY(events[0]);
+    }
+
+    void testFindEventForCancellation()
+    {
+        QFile f(QStringLiteral(SOURCE_DIR "/mergedata/cancellation.rhs.json"));
+        QVERIFY(f.open(QFile::ReadOnly));
+        const auto in = JsonLdDocument::fromJson(QJsonDocument::fromJson(f.readAll()).array());
+        QCOMPARE(in.size(), 1);
+        const auto cancel = in[0];
+
+        MemoryCalendar::Ptr refCal(new MemoryCalendar(QTimeZone::systemTimeZone()));
+        ICalFormat format;
+        format.load(refCal, QStringLiteral(SOURCE_DIR "/calendarhandlerdata/to-be-cancelled.ics"));
+
+        const auto events = CalendarHandler::findEvents(refCal, cancel);
+        QCOMPARE(events.size(), 2);
+        QVERIFY(events[0]);
+        QVERIFY(events[1]);
     }
 };
 
