@@ -1,18 +1,7 @@
 /*
-    Copyright (C) 2018 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2018 Volker Krause <vkrause@kde.org>
 
-    This program is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This program is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <https://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include <KItinerary/Flight>
@@ -284,6 +273,15 @@ private Q_SLOTS:
         QVERIFY(MergeUtil::isSame(res1, res2));
     }
 
+    void testIsSameCancellation()
+    {
+        const auto lhs = JsonLdDocument::fromJson(QJsonDocument::fromJson(readFile(_(SOURCE_DIR "/mergedata/cancellation.lhs.json"))).array());
+        const auto rhs = JsonLdDocument::fromJson(QJsonDocument::fromJson(readFile(_(SOURCE_DIR "/mergedata/cancellation.rhs.json"))).array());
+        QCOMPARE(lhs.size(), 1);
+        QCOMPARE(rhs.size(), 1);
+        QVERIFY(MergeUtil::isSame(lhs[0], rhs[0]));
+    }
+
     void testMerge_data()
     {
         QTest::addColumn<QString>("baseName");
@@ -305,12 +303,18 @@ private Q_SLOTS:
         const auto expected = QJsonDocument::fromJson(readFile(baseName + QLatin1String(".merged.json")));
 
         const auto mergedL2R = MergeUtil::merge(lhs, rhs);
-        //qDebug().noquote() << QJsonDocument(JsonLdDocument::toJson({mergedL2R})).toJson();
-        QCOMPARE(QJsonDocument(JsonLdDocument::toJson(QVector<QVariant>({mergedL2R}))), expected);
+        auto mergedJson = QJsonDocument(JsonLdDocument::toJson(QVector<QVariant>({mergedL2R})));
+        if (mergedJson != expected) {
+            qDebug().noquote() << mergedJson.toJson();
+        }
+        QCOMPARE(mergedJson, expected);
 
         const auto mergedR2L = MergeUtil::merge(rhs, lhs);
-        //qDebug().noquote() << QJsonDocument(JsonLdDocument::toJson({m5ergedR2L})).toJson();
-        QCOMPARE(QJsonDocument(JsonLdDocument::toJson(QVector<QVariant>({mergedR2L}))), expected);
+        mergedJson = QJsonDocument(JsonLdDocument::toJson(QVector<QVariant>({mergedR2L})));
+        if (mergedJson != expected) {
+            qDebug().noquote() << mergedJson.toJson();
+        }
+        QCOMPARE(mergedJson, expected);
     }
 };
 
