@@ -1,20 +1,7 @@
 /*
-   Copyright (c) 2017 Volker Krause <vkrause@kde.org>
+   SPDX-FileCopyrightText: 2017 Volker Krause <vkrause@kde.org>
 
-   This library is free software; you can redistribute it and/or modify it
-   under the terms of the GNU Library General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or (at your
-   option) any later version.
-
-   This library is distributed in the hope that it will be useful, but WITHOUT
-   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-   License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to the
-   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-   02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "config-kitinerary.h"
@@ -73,7 +60,7 @@ static void fillFlightReservation(const QVector<QVariant> &reservations, const K
 static void fillTrainReservation(const TrainReservation &reservation, const KCalendarCore::Event::Ptr &event);
 static void fillBusReservation(const BusReservation &reservation, const KCalendarCore::Event::Ptr &event);
 static void fillLodgingReservation(const QVector<QVariant> &reservations, const KCalendarCore::Event::Ptr &event);
-static void fillEvent(const KItinerary::Event &ev, const KCalCore::Event::Ptr &event);
+static void fillEvent(const KItinerary::Event &ev, const KCalendarCore::Event::Ptr &event);
 static void fillEventReservation(const QVector<QVariant> &reservations, const KCalendarCore::Event::Ptr &event);
 static void fillGeoPosition(const QVariant &place, const KCalendarCore::Event::Ptr &event);
 static void fillFoodReservation(const FoodEstablishmentReservation &reservation, const KCalendarCore::Event::Ptr &event);
@@ -81,15 +68,28 @@ static void fillRentalCarReservation(const RentalCarReservation &reservation, co
 static void fillTaxiReservation(const TaxiReservation &reservation, const KCalendarCore::Event::Ptr &event);
 #endif
 
-QSharedPointer<KCalendarCore::Event> CalendarHandler::findEvent(const QSharedPointer<KCalendarCore::Calendar> &calendar, const QVariant &reservation)
+QVector<QSharedPointer<KCalendarCore::Event> > CalendarHandler::findEvents(const QSharedPointer<KCalendarCore::Calendar> &calendar, const QVariant &reservation)
 {
 #ifdef HAVE_KCAL
     if (!(JsonLd::canConvert<Reservation>(reservation) || JsonLd::canConvert<KItinerary::Event>(reservation)) || !calendar) {
         return {};
     }
 
+    QVector<KCalendarCore::Event::Ptr> events, results;
     const auto dt = SortUtil::startDateTime(reservation).toTimeZone(calendar->timeZone()).date();
-    const auto events = calendar->events(dt);
+    if (dt.isValid()) {
+        // we know the exact day to search at
+        events = calendar->events(dt);
+    } else if (JsonLd::canConvert<Reservation>(reservation)) {
+        // for minimal cancellations, we need to search in a larger range
+        const auto res = JsonLd::convert<Reservation>(reservation);
+        if (!res.modifiedTime().isValid() || res.reservationStatus() != Reservation::ReservationCancelled) {
+            return {};
+        }
+        const auto date = res.modifiedTime().toTimeZone(calendar->timeZone()).date();
+        events = calendar->events(date, date.addDays(180));
+    }
+
     for (const auto &event : events) {
         if (!event->uid().startsWith(QLatin1String("KIT-"))) {
             continue;
@@ -97,16 +97,29 @@ QSharedPointer<KCalendarCore::Event> CalendarHandler::findEvent(const QSharedPoi
         const auto otherRes = CalendarHandler::reservationsForEvent(event);
         for (const auto &other : otherRes) {
             if (MergeUtil::isSame(other, reservation)) {
-                return event;
+                results.push_back(event);
             }
         }
     }
+
+    return results;
 #else
     Q_UNUSED(calendar);
     Q_UNUSED(reservation);
-#endif
-
     return {};
+#endif
+}
+
+QSharedPointer<KCalendarCore::Event> CalendarHandler::findEvent(const QSharedPointer<KCalendarCore::Calendar> &calendar, const QVariant &reservation)
+{
+#ifdef HAVE_KCAL
+    const auto evs = findEvents(calendar, reservation);
+    return evs.empty() ? KCalendarCore::Event::Ptr() : evs.at(0);
+#else
+    Q_UNUSED(calendar);
+    Q_UNUSED(reservation);
+    return {};
+#endif
 }
 
 QVector<QVariant> CalendarHandler::reservationsForEvent(const QSharedPointer<KCalendarCore::Event> &event)
@@ -169,6 +182,12 @@ void CalendarHandler::fillEvent(const QVector<QVariant> &reservations, const QSh
         return;
     }
 
+    if (JsonLd::canConvert<Reservation>(reservation) && JsonLd::convert<Reservation>(reservation).reservationStatus() == Reservation::ReservationCancelled) {
+        event->setTransparency(KCalendarCore::Event::Transparent);
+        event->setSummary(i18nc("canceled train/flight/loding reservation", "Canceled: %1", event->summary()));
+        event->clearAlarms();
+    }
+
     if (!event->uid().startsWith(QLatin1String("KIT-"))) {
         event->setUid(QLatin1String("KIT-") + event->uid());
     }
@@ -353,7 +372,7 @@ static void fillLodgingReservation(const QVector<QVariant> &reservations, const
     event->setDescription(desc.join(QLatin1Char('\n')));
 }
 
-static void fillEvent(const KItinerary::Event &ev, const KCalCore::Event::Ptr &event)
+static void fillEvent(const KItinerary::Event &ev, const KCalendarCore::Event::Ptr &event)
 {
     Place location;
     if (JsonLd::canConvert<Place>(ev.location())) {
