@@ -1,20 +1,7 @@
 /*
-   Copyright (c) 2017 Volker Krause <vkrause@kde.org>
+   SPDX-FileCopyrightText: 2017 Volker Krause <vkrause@kde.org>
 
-   This library is free software; you can redistribute it and/or modify it
-   under the terms of the GNU Library General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or (at your
-   option) any later version.
-
-   This library is distributed in the hope that it will be useful, but WITHOUT
-   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-   License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to the
-   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-   02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "config-kitinerary.h"
@@ -165,7 +152,8 @@ void ExtractorEnginePrivate::extractExternal()
 
     QStringList args({QLatin1String("--type"), ExtractorInput::typeToString(m_inputType),
                       QLatin1String("--context-date"), m_context->m_senderDate.toString(Qt::ISODate),
-                      QLatin1String("--extractors"), extNames.join(QLatin1Char(';'))});
+                      QLatin1String("--extractors"), extNames.join(QLatin1Char(';')),
+                      QLatin1String("--no-validation")});
     const auto extraPaths = m_repo.additionalSearchPaths();
     for (const auto &p : extraPaths) {
         args.push_back(QStringLiteral("--additional-search-path"));
