@@ -1,26 +1,13 @@
 /*
-   Copyright (c) 2017 Volker Krause <vkrause@kde.org>
+   SPDX-FileCopyrightText: 2017 Volker Krause <vkrause@kde.org>
 
-   This library is free software; you can redistribute it and/or modify it
-   under the terms of the GNU Library General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or (at your
-   option) any later version.
-
-   This library is distributed in the hope that it will be useful, but WITHOUT
-   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-   License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to the
-   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-   02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "config-kitinerary.h"
 #include "extractorpostprocessor.h"
 #include "extractorpostprocessor_p.h"
-#include "extractorvalidator_p.h"
+#include "extractorvalidator.h"
 #include "flightpostprocessor_p.h"
 
 #include "extractorutil.h"
@@ -41,6 +28,7 @@
 #include <KItinerary/Place>
 #include <KItinerary/RentalCar>
 #include <KItinerary/Reservation>
+#include <KItinerary/Taxi>
 #include <KItinerary/Ticket>
 #include <KItinerary/TrainTrip>
 #include <KItinerary/Visit>
@@ -64,6 +52,28 @@ using namespace KItinerary;
 ExtractorPostprocessor::ExtractorPostprocessor()
     : d(new ExtractorPostprocessorPrivate)
 {
+    // configure the default set of accepted types, for backward compatibility
+    d->m_validator.setAcceptedTypes<
+        FlightReservation,
+        TrainReservation,
+        BusReservation,
+        RentalCarReservation,
+        TaxiReservation,
+        EventReservation,
+        FoodEstablishmentReservation,
+        LodgingReservation,
+        // reservationFor types
+        Flight,
+        TrainTrip,
+        BusTrip,
+        RentalCar,
+        Taxi,
+        Event,
+        TouristAttractionVisit,
+        FoodEstablishment,
+        // PBI types
+        LocalBusiness
+    >();
 }
 
 ExtractorPostprocessor::ExtractorPostprocessor(ExtractorPostprocessor &&) noexcept = default;
@@ -110,15 +120,10 @@ void ExtractorPostprocessor::process(const QVector<QVariant> &data)
 
 QVector<QVariant> ExtractorPostprocessor::result() const
 {
-    if (!d->m_resultFinalized) {
-        for (auto it = d->m_data.begin(); it != d->m_data.end();) {
-            if (ExtractorValidator::isValidElement(*it)) {
-                ++it;
-            } else {
-                //qCDebug(Log).noquote() << "Discarding element:" << QJsonDocument(JsonLdDocument::toJson({*it})).toJson();
-                it = d->m_data.erase(it);
-            }
-        }
+    if (!d->m_resultFinalized && d->m_validationEnabled) {
+        d->m_data.erase(std::remove_if(d->m_data.begin(), d->m_data.end(), [this](const auto &elem) {
+            return !d->m_validator.isValidElement(elem);
+        }), d->m_data.end());
         d->m_resultFinalized = true;
     }
 
@@ -131,6 +136,11 @@ void ExtractorPostprocessor::setContextDate(const QDateTime& dt)
     d->m_contextDate = dt;
 }
 
+void ExtractorPostprocessor::setValidationEnabled(bool validate)
+{
+    d->m_validationEnabled = validate;
+}
+
 void ExtractorPostprocessorPrivate::mergeOrAppend(const QVariant &elem)
 {
     const auto it = std::find_if(m_data.begin(), m_data.end(), [elem](const QVariant &other) {
@@ -164,14 +174,18 @@ QVariant ExtractorPostprocessorPrivate::processFlightReservation(FlightReservati
         }
     }
 
-    FlightPostProcessor p;
-    res.setReservationFor(p.processFlight(res.reservationFor().value<Flight>()));
+    if (res.reservationFor().isValid()) {
+        FlightPostProcessor p;
+        res.setReservationFor(p.processFlight(res.reservationFor().value<Flight>()));
+    }
     return processReservation(res);
 }
 
 TrainReservation ExtractorPostprocessorPrivate::processTrainReservation(TrainReservation res) const
 {
-    res.setReservationFor(processTrainTrip(res.reservationFor().value<TrainTrip>()));
+    if (res.reservationFor().isValid()) {
+        res.setReservationFor(processTrainTrip(res.reservationFor().value<TrainTrip>()));
+    }
     return processReservation(res);
 }
 
@@ -218,7 +232,7 @@ TrainStation ExtractorPostprocessorPrivate::processTrainStation(TrainStation sta
     if (id.isEmpty()) { // empty -> null cleanup, to have more compact json-ld output
         station.setIdentifier(QString());
     } else if (id.startsWith(QLatin1String("sncf:")) && id.size() == 10) {
-        const auto record = KnowledgeDb::stationForGaresConnexionsId(KnowledgeDb::GaresConnexionsId{id.mid(5)});
+        const auto record = KnowledgeDb::stationForSncfStationId(KnowledgeDb::SncfStationId{id.mid(5)});
         applyStationData(record, station);
         applyStationCountry(id.mid(5, 2).toUpper(), station);
     } else if (id.startsWith(QLatin1String("ibnr:")) && id.size() == 12) {
@@ -236,6 +250,9 @@ TrainStation ExtractorPostprocessorPrivate::processTrainStation(TrainStation sta
         applyStationData(record, station);
     } else if (id.startsWith(QLatin1String("benerail:")) && id.size() == 14) {
         applyStationCountry(id.mid(9, 2).toUpper(), station);
+    } else if (id.startsWith(QLatin1String("vrfi:")) && id.size() >= 7 && id.size() <= 9) {
+        const auto record = KnowledgeDb::stationForVRStationCode(KnowledgeDb::VRStationCode(id.mid(5)));
+        applyStationData(record, station);
     }
 
     return processPlace(station);
@@ -252,14 +269,12 @@ QDateTime ExtractorPostprocessorPrivate::processTrainTripTime(QDateTime dt, cons
     }
 
     QTimeZone tz;
-    if (station.identifier().startsWith(QLatin1String("sncf:"))) {
-        const auto record = KnowledgeDb::stationForGaresConnexionsId(KnowledgeDb::GaresConnexionsId{station.identifier().mid(5)});
-        tz = record.timezone.toQTimeZone();
-    } else if (station.identifier().startsWith(QLatin1String("ibnr:"))) {
-        const auto record = KnowledgeDb::stationForIbnr(KnowledgeDb::IBNR{station.identifier().mid(5).toUInt()});
-        tz = record.timezone.toQTimeZone();
-    } else if (!station.address().addressCountry().isEmpty()) {
-        tz = KnowledgeDb::timezoneForCountry(KnowledgeDb::CountryId{station.address().addressCountry()}).toQTimeZone();
+    const auto geo = station.geo();
+    const KnowledgeDb::CountryId country{station.address().addressCountry()};
+    if (geo.isValid()) {
+        tz = KnowledgeDb::toQTimeZone(KnowledgeDb::timezoneForLocation(geo.latitude(), geo.longitude(), country));
+    } else {
+        tz = KnowledgeDb::toQTimeZone(KnowledgeDb::timezoneForCountry(country));
     }
     if (!tz.isValid()) {
         return dt;
@@ -281,7 +296,9 @@ QDateTime ExtractorPostprocessorPrivate::processTrainTripTime(QDateTime dt, cons
 
 BusReservation ExtractorPostprocessorPrivate::processBusReservation(BusReservation res) const
 {
-    res.setReservationFor(processBusTrip(res.reservationFor().value<BusTrip>()));
+    if (res.reservationFor().isValid()) {
+        res.setReservationFor(processBusTrip(res.reservationFor().value<BusTrip>()));
+    }
     return processReservation(res);
 }
 
@@ -298,9 +315,11 @@ BusTrip ExtractorPostprocessorPrivate::processBusTrip(BusTrip trip) const
 
 LodgingReservation ExtractorPostprocessorPrivate::processLodgingReservation(LodgingReservation res) const
 {
-    res.setReservationFor(processPlace(res.reservationFor().value<LodgingBusiness>()));
-    res.setCheckinTime(processTimeForLocation(res.checkinTime(), res.reservationFor().value<LodgingBusiness>()));
-    res.setCheckoutTime(processTimeForLocation(res.checkoutTime(), res.reservationFor().value<LodgingBusiness>()));
+    if (res.reservationFor().isValid()) {
+        res.setReservationFor(processPlace(res.reservationFor().value<LodgingBusiness>()));
+        res.setCheckinTime(processTimeForLocation(res.checkinTime(), res.reservationFor().value<LodgingBusiness>()));
+        res.setCheckoutTime(processTimeForLocation(res.checkoutTime(), res.reservationFor().value<LodgingBusiness>()));
+    }
     return processReservation(res);
 }
 
@@ -313,7 +332,9 @@ TaxiReservation ExtractorPostprocessorPrivate::processTaxiReservation(TaxiReserv
 
 RentalCarReservation ExtractorPostprocessorPrivate::processRentalCarReservation(RentalCarReservation res) const
 {
-    res.setReservationFor(processRentalCar(res.reservationFor().value<RentalCar>()));
+    if (res.reservationFor().isValid()) {
+        res.setReservationFor(processRentalCar(res.reservationFor().value<RentalCar>()));
+    }
     res.setPickupLocation(processPlace(res.pickupLocation()));
     res.setDropoffLocation(processPlace(res.dropoffLocation()));
     res.setPickupTime(processTimeForLocation(res.pickupTime(), res.pickupLocation()));
@@ -329,9 +350,11 @@ RentalCar ExtractorPostprocessorPrivate::processRentalCar(RentalCar car) const
 
 FoodEstablishmentReservation ExtractorPostprocessorPrivate::processFoodEstablishmentReservation(FoodEstablishmentReservation res) const
 {
-    res.setReservationFor(processPlace(res.reservationFor().value<FoodEstablishment>()));
-    res.setStartTime(processTimeForLocation(res.startTime(), res.reservationFor().value<FoodEstablishment>()));
-    res.setEndTime(processTimeForLocation(res.endTime(), res.reservationFor().value<FoodEstablishment>()));
+    if (res.reservationFor().isValid()) {
+        res.setReservationFor(processPlace(res.reservationFor().value<FoodEstablishment>()));
+        res.setStartTime(processTimeForLocation(res.startTime(), res.reservationFor().value<FoodEstablishment>()));
+        res.setEndTime(processTimeForLocation(res.endTime(), res.reservationFor().value<FoodEstablishment>()));
+    }
     return processReservation(res);
 }
 
@@ -345,7 +368,9 @@ TouristAttractionVisit ExtractorPostprocessorPrivate::processTouristAttractionVi
 
 EventReservation ExtractorPostprocessorPrivate::processEventReservation(EventReservation res) const
 {
-    res.setReservationFor(processEvent(res.reservationFor().value<Event>()));
+    if (res.reservationFor().isValid()) {
+        res.setReservationFor(processEvent(res.reservationFor().value<Event>()));
+    }
     return processReservation(res);
 }
 
@@ -402,7 +427,7 @@ Person ExtractorPostprocessorPrivate::processPerson(Person person) const
     return person;
 }
 
-PostalAddress ExtractorPostprocessorPrivate::processAddress(PostalAddress addr, const QString &phoneNumber)
+PostalAddress ExtractorPostprocessorPrivate::processAddress(PostalAddress addr, const QString &phoneNumber, const GeoCoordinates &geo)
 {
     // convert to ISO 3166-1 alpha-2 country codes
     if (addr.addressCountry().size() > 2) {
@@ -445,6 +470,13 @@ PostalAddress ExtractorPostprocessorPrivate::processAddress(PostalAddress addr,
     }
 #endif
 
+    if (geo.isValid() && addr.addressCountry().isEmpty()) {
+        const auto isoCode = KnowledgeDb::countryForCoordinate(geo.latitude(), geo.longitude());
+        if (isoCode.isValid()) {
+            addr.setAddressCountry(isoCode.toString());
+        }
+    }
+
     addr = ExtractorUtil::extractPostalCode(addr);
     return addr;
 }
@@ -525,7 +557,8 @@ QDateTime ExtractorPostprocessorPrivate::processTimeForLocation(QDateTime dt, co
 
     QTimeZone tz;
     if (!place.address().addressCountry().isEmpty()) {
-        tz = KnowledgeDb::timezoneForCountry(KnowledgeDb::CountryId{place.address().addressCountry()}).toQTimeZone();
+        tz = KnowledgeDb::toQTimeZone(KnowledgeDb::timezoneForLocation(place.geo().latitude(), place.geo().longitude(),
+                                                                       KnowledgeDb::CountryId{place.address().addressCountry()}));
     }
     if (!tz.isValid()) {
         return dt;
