@@ -23,8 +23,7 @@ function main(pass)
 //         return null;
 //     }
 
-    var res = JsonLd.newFlightReservation();
-    res.reservationFor.departureGate = pass.field["gate"].value;
+    var res = Context.data[0];
     res.reservationFor.departureAirport.name = pass.field["origin"].label;
     res.reservationFor.arrivalAirport.name = pass.field["destination"].label;
 
