@@ -19,11 +19,11 @@
 
 function parseText(text) {
     var reservations = new Array();
-    var bookingRef = text.match(/DOSSIER VOYAGE : +([A-Z0-9]{6})/);
+    var bookingRef = text.match(/(?:DOSSIER VOYAGE|BOOKING FILE REFERENCE) : +([A-Z0-9]{6})/);
 
     var pos = 0;
     while (true) {
-        var header = text.substr(pos).match(/ +Départ \/ Arrivée.*\n/);
+        var header = text.substr(pos).match(/ +(?:Départ \/ Arrivée|Departure \/ Arrival).*\n/);
         if (!header)
             break;
         var index = header.index + header[0].length;
@@ -31,14 +31,14 @@ function parseText(text) {
         var res = JsonLd.newTrainReservation();
         res.reservationNumber = bookingRef[1];
 
-        var depLine = text.substr(pos + index).match(/\n {2,3}([\w -]+?)  +(\d{2}\/\d{2}) à (\d{2}h\d{2})/);
+        var depLine = text.substr(pos + index).match(/\n {2,3}([\w -]+?)  +(\d{2}\/\d{2}) (?:à|at) (\d{2}h\d{2})/);
         if (!depLine)
             break;
         index += depLine.index + depLine[0].length;
         res.reservationFor.departureStation.name = depLine[1];
         res.reservationFor.departureTime = JsonLd.toDateTime(depLine[2] + " " + depLine[3], "dd/MM hh'h'mm", "fr");
 
-        var arrLine = text.substr(pos + index).match(/\n {2,3}([\w -]+?)  +(\d{2}\/\d{2}) à (\d{2}h\d{2})/);
+        var arrLine = text.substr(pos + index).match(/\n {2,3}([\w -]+?)  +(\d{2}\/\d{2}) (?:à|at) (\d{2}h\d{2})/);
         if (!arrLine)
             break;
         index += arrLine.index + arrLine[0].length;
@@ -49,13 +49,13 @@ function parseText(text) {
         // since the stations are vertically centered, the stuff we are looking for might be at different
         // positions relative to them
         var legText = text.substring(pos + header.index + header[0].length, pos + index);
-        var trainNumber = legText.match(/TRAIN N° ?(\d{3,4})/);
+        var trainNumber = legText.match(/TRAIN (?:N°|NUMBER) ?(\d{3,5})/);
         if (trainNumber)
             res.reservationFor.trainNumber = trainNumber[1];
-        var seatRes = legText.match(/(VOITURE|COACH) (\d+) - PLACE (\d+)/);
+        var seatRes = legText.match(/(?:VOITURE|COACH) (\d+) - PLACE (\d+)/);
         if (seatRes) {
-            res.reservedTicket.ticketedSeat.seatSection = seatRes[2];
-            res.reservedTicket.ticketedSeat.seatNumber = seatRes[3];
+            res.reservedTicket.ticketedSeat.seatSection = seatRes[1];
+            res.reservedTicket.ticketedSeat.seatNumber = seatRes[2];
         }
 
         reservations.push(res);
@@ -70,39 +70,44 @@ function parseText(text) {
 function parsePdf(pdf) {
     var reservations = new Array();
 
+    var barcode = null;
     for (var i = 0; i < pdf.pageCount; ++i) {
         var page = pdf.pages[i];
 
-        // barcode format:
+        // barcode format: (see https://community.kde.org/KDE_PIM/KItinerary/SNCF_Barcodes)
         // 'i0CV'
         // 6x PNR
-        // 9x document id
+        // 9x document id / e-ticket number
         // '1211'
         // dd/MM/yyyy birthdate
-        // 2x 5x gare & connextion ids of the first leg
+        // 2x 5x SNCF station code of the first leg
         // 5x train number first leg
         // dd/MM travel date
         // 18x client id
         // 19x family name
         // 19x given name
-        // 1x class
-        // 4x stuff
-        // '1' to indicate a second leg, '0' otherwise
-        // 2x 5x gare & connexion ids for the second leg
+        // 1x class first leg ('1' or '2')
+        // 4x tariff/price code
+        // 1x class second leg ('1' or '2'; '0' if there is no second leg)
+        // 2x 5x SNCF station code for the second leg
         // 5x train number second leg
-        var barcode = null;
+        var nextBarcode = null;
         var images = page.imagesInRect(0.75, 0, 1, 0.75);
-        for (var j = 0; j < images.length && !barcode; ++j) {
-            barcode = Barcode.decodeAztec(images[j]);
-            if (barcode.substr(0, 4).toUpperCase() !== "I0CV")
-                barcode = null;
+        for (var j = 0; j < images.length && !nextBarcode; ++j) {
+            nextBarcode = Barcode.decodeAztec(images[j]);
+            if (nextBarcode.substr(0, 4).toUpperCase() !== "I0CV")
+                nextBarcode = null;
         }
+        // Guard against tickets with 3 or more legs, with the second page for the 3rd and subsequent
+        // leg repeating the barcode of the first two legs. One would expect the barcode for the following
+        // legs there, but that doesn't even seem to exists in the sample documents I have for this...
+        barcode = (nextBarcode && nextBarcode != barcode) ? nextBarcode : null;
 
         var underName = null;
         if (barcode) {
             var underName = JsonLd.newObject("Person");
-            underName.familyName = barcode.substring(73, 91).trim();
-            underName.givenName = barcode.substring(92, 110).trim();
+            underName.familyName = barcode.substr(72, 19).trim();
+            underName.givenName = barcode.substr(91, 19).trim();
         }
 
         var legs = parseText(page.text);
@@ -112,7 +117,7 @@ function parsePdf(pdf) {
                 legs[j].reservedTicket.ticketToken = "aztecCode:" + barcode;
                 legs[j].reservationFor.departureStation.identifier = "sncf:" + barcode.substr(j == 0 ? 33 : 116, 5);
                 legs[j].reservationFor.arrivalStation.identifier = "sncf:" + barcode.substr(j == 0 ? 38 : 121, 5);
-                legs[j].reservedTicket.ticketedSeat.seatingType = barcode.substring(110, 111);
+                legs[j].reservedTicket.ticketedSeat.seatingType = barcode.substr(j == 0 ? 110 : 115, 1);
             }
             reservations.push(legs[j]);
         }
