@@ -1,20 +1,7 @@
 /*
-   Copyright (c) 2017 Volker Krause <vkrause@kde.org>
+   SPDX-FileCopyrightText: 2017 Volker Krause <vkrause@kde.org>
 
-   This library is free software; you can redistribute it and/or modify it
-   under the terms of the GNU Library General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or (at your
-   option) any later version.
-
-   This library is distributed in the hope that it will be useful, but WITHOUT
-   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-   License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to the
-   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-   02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "jsonlddocument.h"
@@ -68,6 +55,22 @@ static double doubleValue(const QJsonValue &v)
     return v.toString().toDouble();
 }
 
+static bool isEmptyJsonLdObject(const QJsonObject &obj)
+{
+    for (auto it = obj.begin(); it != obj.end(); ++it) {
+        if (it.key() == QLatin1String("@type")) {
+            continue;
+        }
+        if (it.value().type() != QJsonValue::Object) {
+            return false;
+        }
+        if (!isEmptyJsonLdObject(it.value().toObject())) {
+            return false;
+        }
+    }
+    return true;
+}
+
 static QVariant propertyValue(const QMetaProperty &prop, const QJsonValue &v)
 {
     // enum handling must be done first, as prop.type() == Int
@@ -148,7 +151,11 @@ static QVariant propertyValue(const QMetaProperty &prop, const QJsonValue &v)
         return QVariant::fromValue(l);
     }
 
-    return createInstance(v.toObject());
+    const auto obj = v.toObject();
+    if (prop.userType() == qMetaTypeId<QVariant>() && isEmptyJsonLdObject(obj)) {
+        return {};
+    }
+    return createInstance(obj);
 }
 
 static void createInstance(const QMetaObject *mo, void *v, const QJsonObject &obj)
