@@ -1,20 +1,7 @@
 /*
-   Copyright (c) 2017 Volker Krause <vkrause@kde.org>
+   SPDX-FileCopyrightText: 2017 Volker Krause <vkrause@kde.org>
 
-   This library is free software; you can redistribute it and/or modify it
-   under the terms of the GNU Library General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or (at your
-   option) any later version.
-
-   This library is distributed in the hope that it will be useful, but WITHOUT
-   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-   License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to the
-   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-   02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "airportdb.h"
@@ -35,9 +22,6 @@ namespace KnowledgeDb {
 
 static_assert(alignof(Airport) <= sizeof(Airport), "Airport struct alignment too big!");
 
-static constexpr auto airport_table_size = sizeof(airport_table) / sizeof(Airport);
-static_assert(airport_table_size == sizeof(coordinate_table) / sizeof(KnowledgeDb::Coordinate), "Airport coordinate table size mismatch!");
-
 static bool operator<(const Airport &lhs, IataCode rhs)
 {
     return lhs.iataCode < rhs;
@@ -50,7 +34,7 @@ Coordinate coordinateForAirport(IataCode iataCode)
         return {};
     }
 
-    return coordinate_table[std::distance(std::begin(airport_table), it)];
+    return (*it).coordinate;
 }
 
 QTimeZone timezoneForAirport(IataCode iataCode)
@@ -60,7 +44,7 @@ QTimeZone timezoneForAirport(IataCode iataCode)
         return {};
     }
 
-    return (*it).timezone.toQTimeZone();
+    return KnowledgeDb::toQTimeZone(KnowledgeDb::timezoneForLocation((*it).coordinate.latitude, (*it).coordinate.longitude, (*it).country));
 }
 
 KnowledgeDb::CountryId countryForAirport(IataCode iataCode)
@@ -204,7 +188,12 @@ static void iataCodeForNameFragments(const QStringList &fragments, std::vector<I
 
 static QStringList splitToFragments(const QString &name)
 {
-    return name.split(QRegularExpression(QStringLiteral("[ 0-9/'\"\\(\\)&\\,.–„-]")), QString::SkipEmptyParts);
+    return name.split(QRegularExpression(QStringLiteral("[ 0-9/'\"\\(\\)&\\,.–„-]")),
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
+                      QString::SkipEmptyParts);
+#else
+                      Qt::SkipEmptyParts);
+#endif
 }
 
 }
