@@ -1,18 +1,7 @@
 /*
-    Copyright (C) 2018 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2018 Volker Krause <vkrause@kde.org>
 
-    This program is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This program is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <https://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KITINERARY_LOCATIONUTIL_H
@@ -64,6 +53,8 @@ QString KITINERARY_EXPORT name(const QVariant &location);
 
 /** Computes the distance between to geo coordinates in meters. */
 int KITINERARY_EXPORT distance(const GeoCoordinates &coord1, const GeoCoordinates &coord2);
+/** Computes the distance between to geo coordinates in meters. */
+int KITINERARY_EXPORT distance(float lat1, float lon1, float lat2, float lon2);
 
 /** Location comparison accuracy. */
 enum Accuracy {
