@@ -1,24 +1,14 @@
 /*
-    Copyright (C) 2018 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2018 Volker Krause <vkrause@kde.org>
 
-    This program is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This program is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <https://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "mergeutil.h"
 #include "logging.h"
 #include "compare-logging.h"
 #include "stringutil.h"
+#include "sortutil.h"
 
 #include <KItinerary/BusTrip>
 #include <KItinerary/Event>
@@ -78,6 +68,7 @@ static bool isSameTouristAttraction(const TouristAttraction &lhs, const TouristA
 static bool isSameEvent(const Event &lhs, const Event &rhs);
 static bool isSameRentalCar(const RentalCar &lhs, const RentalCar &rhs);
 static bool isSameTaxiTrip(const Taxi &lhs, const Taxi &rhs);
+static bool isMinimalCancelationFor(const QVariant &r, const Reservation &cancel);
 
 bool MergeUtil::isSame(const QVariant& lhs, const QVariant& rhs)
 {
@@ -90,15 +81,18 @@ bool MergeUtil::isSame(const QVariant& lhs, const QVariant& rhs)
 
     // for all reservations check underName and ticket
     if (JsonLd::canConvert<Reservation>(lhs)) {
+        const auto lhsRes = JsonLd::convert<Reservation>(lhs);
+        const auto rhsRes = JsonLd::convert<Reservation>(rhs);
+
         // for all: underName either matches or is not set
-        const auto lhsUN = JsonLd::convert<Reservation>(lhs).underName().value<Person>();
-        const auto rhsUN = JsonLd::convert<Reservation>(rhs).underName().value<Person>();
+        const auto lhsUN = lhsRes.underName().value<Person>();
+        const auto rhsUN = rhsRes.underName().value<Person>();
         if (!lhsUN.name().isEmpty() && !rhsUN.name().isEmpty() &&  !isSamePerson(lhsUN, rhsUN)) {
             return false;
         }
 
-        const auto lhsTicket = JsonLd::convert<Reservation>(lhs).reservedTicket().value<Ticket>();
-        const auto rhsTicket = JsonLd::convert<Reservation>(rhs).reservedTicket().value<Ticket>();
+        const auto lhsTicket = lhsRes.reservedTicket().value<Ticket>();
+        const auto rhsTicket = rhsRes.reservedTicket().value<Ticket>();
         if (conflictIfPresent(lhsTicket.ticketedSeat().seatNumber(), rhsTicket.ticketedSeat().seatNumber(), Qt::CaseInsensitive)) {
             return false;
         }
@@ -108,6 +102,12 @@ bool MergeUtil::isSame(const QVariant& lhs, const QVariant& rhs)
         if (!JsonLd::isA<FlightReservation>(lhs) && conflictIfPresent(lhsTicket.ticketTokenData(), rhsTicket.ticketTokenData())) {
             return false;
         }
+
+        // one side is a minimal cancelation, matches the reservation number and has a plausible modification time
+        // in this case don't bother comparing content (which will fail), we accept this directly
+        if (isMinimalCancelationFor(lhs, rhsRes) || isMinimalCancelationFor(rhs, lhsRes)) {
+            return true;
+        }
     }
 
     // flight: booking ref, flight number and departure day match
@@ -587,3 +587,18 @@ QVariant MergeUtil::merge(const QVariant &lhs, const QVariant &rhs)
 
     return res;
 }
+
+bool isMinimalCancelationFor(const QVariant &r, const Reservation &cancel)
+{
+    const auto res = JsonLd::convert<Reservation>(r);
+    if (res.reservationStatus() == Reservation::ReservationCancelled || cancel.reservationStatus() != Reservation::ReservationCancelled) {
+        return false;
+    }
+    if (!equalAndPresent(res.reservationNumber(), cancel.reservationNumber())) {
+        return false;
+    }
+    if (!cancel.modifiedTime().isValid() || !cancel.reservationFor().isNull()) {
+        return false;
+    }
+    return SortUtil::startDateTime(r) > cancel.modifiedTime();
+}
